@@ -27,15 +27,23 @@
  * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
  */
 
-#ifndef lint
-static char rcsid[] = "$Header: /user6/ouster/wish/RCS/tkMain.c,v 1.99 93/11/11 09:35:24 ouster Exp $ SPRITE (Berkeley)";
-#endif
+/*  #ifndef lint */
+/*  static char rcsid[] = "$Header: /user6/ouster/wish/RCS/tkMain.c,v 1.99 93/11/11 09:35:24 ouster Exp $ SPRITE (Berkeley)"; */
+/*  #endif */
 
+#include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <tcl.h>
 #include <tk.h>
 
+
+
+#if (TK_MINOR_VERSION==0 && TK_MAJOR_VERSION==4)
+#define TkCreateMainWindow Tk_CreateMainWindow
+#endif
+
+
 /*-------------------------------------------------------------------*/
 #include <unistd.h>
 #include <sys/types.h>
@@ -67,7 +75,7 @@ static Tk_Window mainWindow;	/* The main window for the application.  If
 				 * NULL then the application no longer
 				 * exists. */
 static Tcl_Interp *interp;	/* Interpreter for this application. */
-char *tcl_RcFileName = NULL;	/* Name of a user-specific startup script
+char *tcl_RcFileName;		/* Name of a user-specific startup script
 				 * to source if the application is being run
 				 * interactively (e.g. "~/.wishrc").  Set
 				 * by Tcl_AppInit.  NULL means don't source
@@ -90,28 +98,32 @@ static char *display = NULL;
 static char *geometry = NULL;
 int debug = 0;
 
-void guiCreateCommand _ANSI_ARGS_((int idLispObject, int iSlot , char *arglist));
+static void guiCreateCommand _ANSI_ARGS_((int idLispObject, int iSlot , char *arglist));
 
-dfprintf(fp,s,x0,x1,x2,x3,x4,x5)
-     char *s;
-     FILE *fp;
-     int x0,x1,x2,x3,x4,x5;
-{if (debug)
-   {fprintf(fp,"\nguis:");
-    fprintf(fp,s,x0,x1,x2,x3,x4,x5);
-    fflush(stderr);
+void
+dfprintf(FILE *fp,char *s,...) {
+
+  va_list args;
+
+  if (debug) {
+    va_start(args,s);
+    fprintf(fp,"\nguis:");
+    vfprintf(fp,s,args);
+    fflush(fp);
+    va_end(args);
   }
 }
 
 #define CMD_SIZE 4000
 #define SIGNAL_ERROR TCL_signal_error
 
+static void
 TCL_signal_error(x)
      char *x;
 {char buf[300] ;
  sprintf("error %s",x);
  Tcl_Eval(interp,buf);
- dfprintf(x);
+ dfprintf(stderr,x);
 }
 
 
@@ -168,6 +180,11 @@ static void		StdinProc _ANSI_ARGS_((ClientData clientData,
 int
 main(argc, argv)
 */
+
+/* FIXME, should come in from tk header or not be called */
+EXTERN Tk_Window	TkCreateMainWindow _ANSI_ARGS_((Tcl_Interp * interp, 
+				char * screenName, char * baseName));
+
 void
 TkX_Wish (argc, argv)
     int argc;				/* Number of arguments. */
@@ -219,14 +236,16 @@ TkX_Wish (argc, argv)
      * Initialize the Tk application.
      */
 
-    mainWindow = Tk_CreateMainWindow(interp, display, name, "Tk"); 
+    mainWindow = TkCreateMainWindow(interp, display, name/*  , "Tk" */); 
     if (mainWindow == NULL) {
 	fprintf(stderr, "%s\n", interp->result);
 	exit(1);
     }
+#ifndef __MINGW32__    
     if (synchronize) {
 	XSynchronize(Tk_Display(mainWindow), True);
     }
+#endif    
     Tk_GeometryRequest(mainWindow, 200, 200);
     Tk_UnmapWindow(mainWindow);
 
@@ -325,8 +344,9 @@ TkX_Wish (argc, argv)
 	}
 
 	dfprintf(stderr, "guis : Creating file handler for %d\n", dsfd->fd);
-	
+#ifndef __MINGW32__	
 	Tk_CreateFileHandler(dsfd->fd, TK_READABLE, StdinProc, (ClientData) 0);
+#endif        
     }
     fflush(stdout);
     Tcl_DStringInit(&command);
@@ -359,7 +379,7 @@ error:
 
 static char *being_set_by_lisp;
 
-char *
+static char *
 tell_lisp_var_changed(
                 clientData,
                interp,
@@ -378,13 +398,14 @@ tell_lisp_var_changed(
   if (being_set_by_lisp == 0)
     { char *val = Tcl_GetVar2(interp,name1,name2, TCL_GLOBAL_ONLY);
       char buf[3];
-      STORE_3BYTES(buf,(int) clientData);
+      STORE_3BYTES(buf,(long) clientData);
       if(sock_write_str2(dsfd,   m_set_lisp_loc, buf, 3 ,
 				 val, strlen(val))
 		 < 0)
 		{		/* what do we want to do if the write failed */}
-	      
+#ifndef __MINGW32__	      
     if (parent > 0)  kill(parent, SIGUSR1);
+#endif      
     }
   else
   /* avoid going back to lisp if it is lisp that is doing the setting! */
@@ -441,7 +462,6 @@ StdinProc(clientData, mask)
 
   do
     { 
-      char *p;
 
       msg = guiParseMsg1(dsfd,buf,sizeof(buf));
 
@@ -449,7 +469,9 @@ StdinProc(clientData, mask)
 	{
 	  /*dfprintf(stderr, "Yoo !!! Empty command\n"); */
 	  if (debug)perror("zero message");
+#ifndef __MINGW32__          
 	  Tk_CreateFileHandler(dsfd->fd, TK_READABLE, StdinProc, (ClientData) 0);
+#endif          
 	  return;
 	}
 
@@ -457,10 +479,7 @@ StdinProc(clientData, mask)
       switch (msg->type){
       case m_create_command:
 	  {
-	    int idLispObject;
 	    int iSlot;
-	    char *arglist;
-	    int matches;
 	    GET_3BYTES(msg->body,iSlot);
 	    guiCreateCommand(0, iSlot, &(msg->body[3]));
 	  }
@@ -477,7 +496,6 @@ StdinProc(clientData, mask)
 	    {
 	      unsigned char buf[4];
 	      unsigned char *p = buf;
-	      int cb;
 	      /*header */
 	      *p++ = (code ? '1' : '0');
 	      bcopy(msg->msg_id,p,3);
@@ -489,8 +507,10 @@ StdinProc(clientData, mask)
 	      
 	      if (msg->type == m_tcl_command_wait_response)
 		{ /* parent is waiting so dong signal */ ;}
+#ifndef __MINGW32__              
 	      else
 		if (parent> 0)kill(parent, SIGUSR1);
+#endif              
 	    }
 
 	  Tcl_DStringFree(&command);
@@ -500,12 +520,12 @@ StdinProc(clientData, mask)
 	  {
 	    Tcl_DStringInit(&command);
 	    Tcl_DStringFree(&command);
-	    fSclear_connection(dsfd);
+	    fSclear_connection(dsfd->fd);
 	  }
 	  break;
 	case m_tcl_set_text_variable:
 	  { int n = strlen(msg->body);
-	    if(being_set_by_lisp) fprintf(stderr,"recursive set %d?");
+	    if(being_set_by_lisp) fprintf(stderr,"recursive set?");
 	    /* avoid a trace on this set!! */
 	    
 	    being_set_by_lisp = msg->body;
@@ -516,8 +536,7 @@ StdinProc(clientData, mask)
 	  break;
 
 	case m_tcl_link_text_variable:
-	  {int i;
-	   char buf[30];
+	  {long i;
 	   GET_3BYTES(msg->body,i);
 	   Tcl_TraceVar2(interp,msg->body+3 ,0,
 			   TCL_TRACE_WRITES
@@ -528,8 +547,7 @@ StdinProc(clientData, mask)
 	   break;
 
 	case m_tcl_unlink_text_variable:
-	  {int i;
-	   char buf[30];
+	  {long i;
 	   GET_3BYTES(msg->body,i);
 	   Tcl_UntraceVar2(interp,msg->body+3 ,0,
 			   TCL_TRACE_WRITES
@@ -543,8 +561,7 @@ StdinProc(clientData, mask)
 	  dfprintf(stderr, "Error !!! Unknown command %d\n"
 		   , msg->type);
 	}
-    prompt:
-      fNotDone = fScheck_dsfd_for_input(dsfd,0);
+      fNotDone = fix(fScheck_dsfd_for_input(dsfd,0));
       
       if (fNotDone > 0)
 	{
@@ -578,7 +595,7 @@ TclGenericCommandProcedure( clientData,
 {
   char szCmd[CMD_SIZE];
   ClientDataLispObject *pcdlo = (ClientDataLispObject *)clientData;
-  int cb;
+  int cb=0;
   char *q = szCmd;
   char *p = pcdlo->arglist;
 
@@ -616,13 +633,15 @@ TclGenericCommandProcedure( clientData,
 	      , szCmd, dsfd->fd, errno, cb);
 
     }
+#ifndef __MINGW32__  
   if (parent > 0)kill(parent, SIGUSR1);
+#endif  
   return TCL_OK;
 }
 
 
 
-void
+static void
 guiCreateCommand( idLispObject,  iSlot , arglist)
      int idLispObject; int iSlot ; char *arglist;
 {
@@ -672,14 +691,14 @@ guiBindCallback(char *szNameCmdProc, char *szTclObject, char *szModifier,char* a
   return code;
 }
 */
-void
-guiDeleteCallback(szCallback)
-     char *szCallback;
-{
-  dfprintf(stderr, "Tcl Deleting command : %s\n", szCallback);
+/* static void */
+/* guiDeleteCallback(szCallback) */
+/*      char *szCallback; */
+/* { */
+/*   dfprintf(stderr, "Tcl Deleting command : %s\n", szCallback); */
 
-  Tcl_DeleteCommand(interp, szCallback);
-}
+/*   Tcl_DeleteCommand(interp, szCallback); */
+/* } */
 
 /*  */
 
