@@ -27,30 +27,50 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "num_include.h"
 
-object
-bignum2(most, least)
-int most, least;
-{ static  plong u [4] 
-   = {0x01010004 ,0x01010004, 0,0};
-  GEN w;
-  int l;
-  if(most) {setlgef(u,4),l=4;}
-    else {l=3; setlgef(u,3);}
-  MP_START_LOW(w,u,l);
-  MP_NEXT_UP(w) = least;
-  if (most) MP_NEXT_UP(w) = most;
- return  make_integer(u);
+static void
+zero_divisor(void);
+
+object fixnum_add(int i, int j)
+{
+
+  if (i>=0)
+   { if (j<= (MOST_POSITIVE_FIX-i))
+      { MYmake_fixnum(return,i+j);
+      }
+   MPOP(return,addss,i,j);
+   } else { /* i < 0 */
+     if ((MOST_NEG_FIXNUM -i) <= j) {
+       MYmake_fixnum(return,i+j);
+     }
+   MPOP(return,addss,i,j);
+   }
+}
+/* return i - j */
+object fixnum_sub(int i, int j)
+{  
+
+  if (i>=0)
+   { if (j >= (i - MOST_POSITIVE_FIX))
+      { MYmake_fixnum(return,i-j);
+      }
+   MPOP(return,subss,i,j);
+   } else { /* i < 0 */
+     if ((MOST_NEG_FIXNUM -i) <= -j) {
+       MYmake_fixnum(return,i-j);
+     }
+   MPOP(return,subss,i,j);
+   }
 }
 
-object
-fixnum_times(i, j)
-int i, j;
-{ MPOP(return,mulss,i,j);
-}
+/* static object */
+/* fixnum_times(int i, int j) */
+/* { */
 
-object
-number_to_complex(x)
-object x;
+/*   MPOP(return,mulss,i,j); */
+/* } */
+
+static object
+number_to_complex(object x)
 {
 	object z;
 
@@ -71,33 +91,26 @@ object x;
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-number_plus(x, y)
-object x, y;
+number_plus(object x, object y)
 {
-	int i, j, k;
 	double dx, dy;
-	object z, z1;
-	vs_mark;
-	
+	object z;
 	switch (type_of(x)) {
-
 	case t_fixnum:
 		switch(type_of(y)) {
 		case t_fixnum:
-		  MPOP(return, addss,fix(x),fix(y));
+		  return fixnum_add(fix(x),fix(y));
 		case t_bignum:
 		  MPOP(return, addsi,fix(x),MP(y));
 		case t_ratio:
-			vs_push(number_times(x, y->rat.rat_den));
-			z = number_plus(vs_top[-1], y->rat.rat_num);
-			vs_push(z);
-			z = make_ratio(z, y->rat.rat_den);
-			vs_reset;
-			return(z);
+			z = number_plus(number_times(x, y->rat.rat_den),
+					y->rat.rat_num);
+			return make_ratio(z, y->rat.rat_den);
 		case t_shortfloat:
 			dx = (double)(fix(x));
 			dy = (double)(sf(y));
@@ -119,12 +132,8 @@ object x, y;
 		case t_bignum:
 		  MPOP(return,addii,MP(y),MP(x)); 
 		case t_ratio:
-			vs_push(number_times(x, y->rat.rat_den));
-			z = number_plus(vs_top[-1], y->rat.rat_num);
-			vs_push(z);
-			z = make_ratio(z, y->rat.rat_den);
-			vs_reset;
-			return(z);
+			z = number_plus(number_times(x, y->rat.rat_den), y->rat.rat_num);
+			return make_ratio(z, y->rat.rat_den);
 		case t_shortfloat:
 			dx = number_to_double(x);
 			dy = (double)(sf(y));
@@ -143,20 +152,16 @@ object x, y;
 		switch (type_of(y)) {
 		case t_fixnum:
 		case t_bignum:
-			vs_push(number_times(x->rat.rat_den, y));
-			z = number_plus(x->rat.rat_num, vs_top[-1]);
-			vs_push(z);
+			
+			z = number_plus(x->rat.rat_num,
+					number_times(x->rat.rat_den, y));
 			z = make_ratio(z, x->rat.rat_den);
-			vs_reset;
 			return(z);
 		case t_ratio:
-			vs_push(number_times(x->rat.rat_num,y->rat.rat_den));
-			vs_push(number_times(x->rat.rat_den,y->rat.rat_num));
-			z = number_plus(vs_top[-2], vs_top[-1]);
-			vs_push(z);
-			vs_push(number_times(x->rat.rat_den,y->rat.rat_den));
-			z = make_ratio(z, vs_top[-1]);
-			vs_reset;
+
+			z = number_plus(number_times(x->rat.rat_num,y->rat.rat_den),
+					number_times(x->rat.rat_den,y->rat.rat_num));
+			z = make_ratio(z,number_times(x->rat.rat_den,y->rat.rat_den));
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -224,40 +229,37 @@ object x, y;
 	case t_complex:
 	COMPLEX:
 		x = number_to_complex(x);
-		vs_push(x);
 		y = number_to_complex(y);
-		vs_push(y);
-		vs_push(number_plus(x->cmp.cmp_real, y->cmp.cmp_real));
-		vs_push(number_plus(x->cmp.cmp_imag, y->cmp.cmp_imag));
-		z = make_complex(vs_top[-2], vs_top[-1]);
-		vs_reset;
+		z = make_complex(number_plus(x->cmp.cmp_real, y->cmp.cmp_real),
+				 number_plus(x->cmp.cmp_imag, y->cmp.cmp_imag));
 		return(z);
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-one_plus(x)
-object x;
+one_plus(object x)
 {
-	int i;
 	double dx;
-	object z, z1;
-	vs_mark;
+	object z;
+
 	
 	switch (type_of(x)) {
 
 	case t_fixnum:
-	  MPOP(return, addss,1,fix(x));
+	  
+	  if (fix(x)< MOST_POSITIVE_FIX-1) {
+	    MYmake_fixnum(return,fix(x)+1);
+	  }
+	  MPOP(return,addss,1,fix(x));
 	case t_bignum:
-	  MPOP(return, addsi,1,MP(x));
+	  MPOP(return,addsi,1,MP(x));
 	case t_ratio:
 		z = number_plus(x->rat.rat_num, x->rat.rat_den);
-		vs_push(z);
 		z = make_ratio(z, x->rat.rat_den);
-		vs_reset;
 		return(z);
 
 	case t_shortfloat:
@@ -273,41 +275,33 @@ object x;
 		return(z);
 
 	case t_complex:
-	COMPLEX:
-		vs_push(one_plus(x->cmp.cmp_real));
-		z = make_complex(vs_top[-1], x->cmp.cmp_imag);
-		vs_reset;
+		z = make_complex(one_plus(x->cmp.cmp_real), x->cmp.cmp_imag);
 		return(z);
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-number_minus(x, y)
-object x, y;
+number_minus(object x, object y)
 {
-	int i, j, k;
 	double dx, dy;
-	object z, z1;
-	vs_mark;
+	object z;
+
 	
 	switch (type_of(x)) {
 
 	case t_fixnum:
 		switch(type_of(y)) {
-#define MOST_NEG_FIXNUM (1 << 31)		  
 		case t_fixnum:
 		  MPOP(return,subss,fix(x),fix(y));
 		case t_bignum:
 		  MPOP(return, subsi,fix(x),MP(y));
 		case t_ratio:
-			vs_push(number_times(x, y->rat.rat_den));
-			z = number_minus(vs_top[-1], y->rat.rat_num);
-			vs_push(z);
+			z = number_minus(number_times(x, y->rat.rat_den), y->rat.rat_num);
 			z = make_ratio(z, y->rat.rat_den);
-			vs_reset;
 			return(z);
 		case t_shortfloat:
 			dx = (double)(fix(x));
@@ -330,11 +324,8 @@ object x, y;
 		case t_bignum:
 		  MPOP(return,subii,MP(x),MP(y));
 		case t_ratio:
-			vs_push(number_times(x, y->rat.rat_den));
-			z = number_minus(vs_top[-1], y->rat.rat_num);
-			vs_push(z);
+			z = number_minus(number_times(x, y->rat.rat_den), y->rat.rat_num);
 			z = make_ratio(z, y->rat.rat_den);
-			vs_reset;
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -354,20 +345,13 @@ object x, y;
 		switch (type_of(y)) {
 		case t_fixnum:
 		case t_bignum:
-			vs_push(number_times(x->rat.rat_den, y));
-			z = number_minus(x->rat.rat_num, vs_top[-1]);
-			vs_push(z);
+			z = number_minus(x->rat.rat_num, number_times(x->rat.rat_den, y));
 			z = make_ratio(z, x->rat.rat_den);
-			vs_reset;
 			return(z);
 		case t_ratio:
-			vs_push(number_times(x->rat.rat_num,y->rat.rat_den));
-			vs_push(number_times(x->rat.rat_den,y->rat.rat_num));
-			z = number_minus(vs_top[-2], vs_top[-1]);
-			vs_push(z);
-			vs_push(number_times(x->rat.rat_den,y->rat.rat_den));
-			z = make_ratio(z, vs_top[-1]);
-			vs_reset;
+			z = number_minus(number_times(x->rat.rat_num,y->rat.rat_den),
+					 (number_times(x->rat.rat_den,y->rat.rat_num)));
+			z = make_ratio(z,number_times(x->rat.rat_den,y->rat.rat_den));
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -434,29 +418,22 @@ object x, y;
 	case t_complex:
 	COMPLEX:
 		x = number_to_complex(x);
-		vs_push(x);
 		y = number_to_complex(y);
-		vs_push(y);
-		vs_push(number_minus(x->cmp.cmp_real, y->cmp.cmp_real));
-		vs_push(number_minus(x->cmp.cmp_imag, y->cmp.cmp_imag));
-		z = make_complex(vs_top[-2], vs_top[-1]);
-		vs_reset;
+		z = make_complex(number_minus(x->cmp.cmp_real, y->cmp.cmp_real),
+				 number_minus(x->cmp.cmp_imag, y->cmp.cmp_imag));
 		return(z);
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-one_minus(x)
-object x;
+one_minus(object x)
 {
-	int i;
 	double dx;
-	object z, z1;
-	vs_mark;
-	
+	object z;
 	switch (type_of(x)) {
 
 	case t_fixnum:
@@ -465,9 +442,7 @@ object x;
 	  MPOP(return,addsi,-1,MP(x));
 	case t_ratio:
 		z = number_minus(x->rat.rat_num, x->rat.rat_den);
-		vs_push(z);
 		z = make_ratio(z, x->rat.rat_den);
-		vs_reset;
 		return(z);
 
 	case t_shortfloat:
@@ -483,40 +458,34 @@ object x;
 		return(z);
 
 	case t_complex:
-	COMPLEX:
-		vs_push(one_minus(x->cmp.cmp_real));
-		z = make_complex(vs_top[-1], x->cmp.cmp_imag);
-		vs_reset;
+		z = make_complex(one_minus(x->cmp.cmp_real), x->cmp.cmp_imag);
 		return(z);
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-number_negate(x)
-object x;
+number_negate(object x)
 {
 	object	z, z1;
-	vs_mark;
 
 	switch (type_of(x)) {
 
 	case t_fixnum:
 		if(fix(x) == MOST_NEGATIVE_FIX)
-		  return make_bignum(ABS_MOST_NEGS);
+		  return fixnum_add(1,MOST_POSITIVE_FIX);
 		else
 		  return(make_fixnum(-fix(x)));
 	case t_bignum:
 		return big_minus(x);
 	case t_ratio:
 		z1 = number_negate(x->rat.rat_num);
-		vs_push(z1);
 		z = alloc_object(t_ratio);
 		z->rat.rat_num = z1;
 		z->rat.rat_den = x->rat.rat_den;
-		vs_reset;
 		return(z);
 
 	case t_shortfloat:
@@ -530,24 +499,21 @@ object x;
 		return(z);
 
 	case t_complex:
-		vs_push(number_negate(x->cmp.cmp_real));
-		vs_push(number_negate(x->cmp.cmp_imag));
-		z = make_complex(vs_top[-2], vs_top[-1]);
-		vs_reset;
+		z = make_complex(number_negate(x->cmp.cmp_real),
+				 number_negate(x->cmp.cmp_imag));
 		return(z);
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-number_times(x, y)
-object x, y;
-{
+number_times(object x, object y)
+{  
 	object z;
 	double dx, dy;
-	vs_mark;
 
 	switch (type_of(x)) {
 
@@ -558,9 +524,7 @@ object x, y;
 		case t_bignum:
 		  MPOP(return,mulsi,fix(x),MP(y));
 		case t_ratio:
-			vs_push(number_times(x, y->rat.rat_num));
-			z = make_ratio(vs_top[-1], y->rat.rat_den);
-			vs_reset;
+			z = make_ratio(number_times(x, y->rat.rat_num), y->rat.rat_den);
 			return(z);
 		case t_shortfloat:
 			dx = (double)(fix(x));
@@ -584,9 +548,7 @@ object x, y;
 		case t_bignum:
 		  MPOP(return,mulii,MP(y),MP(x));
 		case t_ratio:
-			vs_push(number_times(x, y->rat.rat_num));
-			z = make_ratio(vs_top[-1], y->rat.rat_den);
-			vs_reset;
+			z = make_ratio(number_times(x, y->rat.rat_num), y->rat.rat_den);
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -606,15 +568,11 @@ object x, y;
 		switch (type_of(y)) {
 		case t_fixnum:
 		case t_bignum:
-			vs_push(number_times(x->rat.rat_num, y));
-			z = make_ratio(vs_top[-1], x->rat.rat_den);
-			vs_reset;
+			z = make_ratio(number_times(x->rat.rat_num, y), x->rat.rat_den);
 			return(z);
 		case t_ratio:
-			vs_push(number_times(x->rat.rat_num,y->rat.rat_num));
-			vs_push(number_times(x->rat.rat_den,y->rat.rat_den));
-			z = make_ratio(vs_top[-2], vs_top[-1]);
-			vs_reset;
+			z = make_ratio(number_times(x->rat.rat_num,y->rat.rat_num),
+				       number_times(x->rat.rat_den,y->rat.rat_den));
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -684,38 +642,28 @@ object x, y;
 		object z1, z2, z11, z12, z21, z22;
 
 		x = number_to_complex(x);
-		vs_push(x);
 		y = number_to_complex(y);
-		vs_push(y);
 		z11 = number_times(x->cmp.cmp_real, y->cmp.cmp_real);
-		vs_push(z11);
 		z12 = number_times(x->cmp.cmp_imag, y->cmp.cmp_imag);
-		vs_push(z12);
 		z21 = number_times(x->cmp.cmp_imag, y->cmp.cmp_real);
-		vs_push(z21);
 		z22 = number_times(x->cmp.cmp_real, y->cmp.cmp_imag);
-		vs_push(z22);
 		z1 =  number_minus(z11, z12);
-		vs_push(z1);
 		z2 =  number_plus(z21, z22);
-		vs_push(z2);
 		z = make_complex(z1, z2);
-		vs_reset;
 		return(z);
 	}
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
 object
-number_divide(x, y)
-object x, y;
+number_divide(object x, object y)
 {
 	object z;
 	double dx, dy;
-	vs_mark;
 
 	switch (type_of(x)) {
 
@@ -728,19 +676,14 @@ object x, y;
 				zero_divisor();
 			if (number_minusp(y) == TRUE) {
 				x = number_negate(x);
-				vs_push(x);
 				y = number_negate(y);
-				vs_push(y);
 			}
 			z = make_ratio(x, y);
-			vs_reset;
 			return(z);
 		case t_ratio:
 			if(number_zerop(y->rat.rat_num))
 				zero_divisor();
-			vs_push(number_times(x, y->rat.rat_den));
-			z = make_ratio(vs_top[-1], y->rat.rat_num);
-			vs_reset;
+			z = make_ratio(number_times(x, y->rat.rat_den), y->rat.rat_num);
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -762,15 +705,11 @@ object x, y;
 		case t_bignum:
 			if (number_zerop(y))
 				zero_divisor();
-			vs_push(number_times(x->rat.rat_den, y));
-			z = make_ratio(x->rat.rat_num, vs_top[-1]);
-			vs_reset;
+			z = make_ratio(x->rat.rat_num, number_times(x->rat.rat_den, y));
 			return(z);
 		case t_ratio:
-			vs_push(number_times(x->rat.rat_num,y->rat.rat_den));
-			vs_push(number_times(x->rat.rat_den,y->rat.rat_num));
-			z = make_ratio(vs_top[-2], vs_top[-1]);
-			vs_reset;
+			z = make_ratio(number_times(x->rat.rat_num,y->rat.rat_den),
+				       number_times(x->rat.rat_den,y->rat.rat_num));
 			return(z);
 		case t_shortfloat:
 			dx = number_to_double(x);
@@ -845,159 +784,31 @@ object x, y;
 		object z1, z2, z3;
 
 		x = number_to_complex(x);
-		vs_push(x);
 		y = number_to_complex(y);
-		vs_push(y);
 		z1 = number_times(y->cmp.cmp_real, y->cmp.cmp_real);
-		vs_push(z1);
 		z2 = number_times(y->cmp.cmp_imag, y->cmp.cmp_imag);
-		vs_push(z2);
 		if (number_zerop(z3 = number_plus(z1, z2)))
 			zero_divisor();
-		vs_push(z3);
 		z1 = number_times(x->cmp.cmp_real, y->cmp.cmp_real);
-		vs_push(z1);
 		z2 = number_times(x->cmp.cmp_imag, y->cmp.cmp_imag);
-		vs_push(z2);
 		z1 = number_plus(z1, z2);
-		vs_push(z1);
 		z = number_times(x->cmp.cmp_imag, y->cmp.cmp_real);
-		vs_push(z);
 		z2 = number_times(x->cmp.cmp_real, y->cmp.cmp_imag);
-		vs_push(z2);
 		z2 = number_minus(z, z2);
-		vs_push(z2);
 		z1 = number_divide(z1, z3);
-		vs_push(z1);
 		z2 = number_divide(z2, z3);
-		vs_push(z2);
 		z = make_complex(z1, z2);
-		vs_reset;
 		return(z);
 	}
 
 	default:
 		FEwrong_type_argument(sLnumber, x);
+		return(Cnil);
 	}
 }
 
-integer_quotient_remainder_1(x, y, qp, rp)
-object x, y;
-object *qp, *rp;
-{  GEN res,quot,x0,y0;
-  save_avma;
-  if (type_of(x)==t_fixnum) x0 = stoi(fix(x));
-   else x0=MP(x); 
-  if (type_of(y)==t_fixnum) y0 = stoi(fix(y));
-   else y0=MP(y);
-  res = dvmdii(x0,y0,&quot);
-  restore_avma;
-  *qp = make_integer(res);
-  *rp = make_integer(quot);
-  return;
- }
-      
-
-/* old
-integer_quotient_remainder_1(x, y, qp, rp)
-object x, y;
-object *qp, *rp;
-{
-	enum type tx, ty;
-	int i, j, q, r;
-	vs_mark;
-		
-	tx = type_of(x);
-	ty = type_of(y);
-	if (tx == t_fixnum) {
- 		if (ty == t_fixnum) {
-			if (fix(y) == 0)
-				zero_divisor();
-			if (fix(y) == MOST_NEGATIVE_FIX)
-				if (fix(x) == MOST_NEGATIVE_FIX) {
-					*qp = small_fixnum(1);
-					*rp = small_fixnum(0);
-					return;
-				} else {
-					*qp = small_fixnum(0);
-					*rp = x;
-					return;
-				}
-			if (fix(x) == MOST_NEGATIVE_FIX) {
-				if (fix(y) == 1) {
-					*qp = x;
-					*rp = small_fixnum(0);
-					return;
-				}
-				if (fix(y) == -1) {
-					*qp = bignum2(1, 0);
-					*rp = small_fixnum(0);
-					return;
-				}
-				if (fix(y) > 0) {
-					extended_div(fix(y), 1, 0,
-						     &q, &r);
-					*qp = make_fixnum(-q);
-					vs_push(*qp);
-					*rp = make_fixnum(-r);
-					vs_reset;
-					return;
-				} else {
-					extended_div(-fix(y), 1, 0,
-						     &q, &r);
-					*qp = make_fixnum(q);
-					vs_push(*qp);
-					*rp = make_fixnum(-r);
-					vs_reset;
-					return;
-				}
-			}
-			*qp = make_fixnum(fix(x) / fix(y));
-			vs_push(*qp);
-			*rp = make_fixnum(fix(x) % fix(y));
-			vs_reset;
-			return;
-		}
-		if (ty == t_bignum) {
-			if (fix(x) == MOST_NEGATIVE_FIX &&
-			    MP(y)[2] == MOST_NEGATIVE_FIX &&
-			    lgef(MP(y)) == 1 &&
-			    signe(MP(y)) < 0)
-			  {
-				*qp = small_fixnum(-1);
-				*rp = small_fixnum(0);
-				return;
-			      }
-			*qp = small_fixnum(0);
-			*rp = x;
-			return;
-		} else
-			FEwrong_type_argument(sLinteger, y);
-	}
-	if (tx == t_bignum) {
-		if (ty == t_fixnum)
-		  { 
-		     MPOP(*qp = ,divis,MP(x),fix(y));
-		     *rp = make_fixnum(hiremainder);
-		     return;
-		   }
-		else
-		  if (ty == t_bignum)
-#define Dvmdii(a,b) dvmdii(a,b,&p1)
-		    {GEN p1;
-		     MPOP(*qp = ,dvmdii,MP(x),MP(y));
-		     *rp = make_integer(p1);
-		     return;}
-		else
-			FEwrong_type_argument(sLinteger, y);
-	}
-	FEwrong_type_argument(sLinteger, x);
-}
-*/
-
 object
-integer_divide1(x, y)
-object x, y;
+integer_divide1(object x, object y)
 {
 	object q, r;
 
@@ -1006,19 +817,15 @@ object x, y;
 }
 
 object
-get_gcd(x, y)
-object	x, y;
+get_gcd(object x, object y)
 {
 	int	i, j, k;
 	object	q, r;
-	vs_mark;
 
 	if (number_minusp(x))
 		x = number_negate(x);
-	vs_push(x);
 	if (number_minusp(y))
 		y = number_negate(y);
-	vs_push(y);
 
 L:
 	if (type_of(x) == t_fixnum && type_of(y) == t_fixnum) {
@@ -1031,7 +838,6 @@ LL:
 			j = k;
 		}
 		if (j == 0) {
-			vs_reset;
 			return(make_fixnum(i));
 		}
 		k = i % j;
@@ -1046,17 +852,17 @@ LL:
 		y = r;
 	}
 	if (type_of(y) == t_fixnum && fix(y) == 0) {
-		vs_reset;
 		return(x);
 	}
 	integer_quotient_remainder_1(x, y, &q, &r);
-	vs_top[-2] = x = y;
-	vs_top[-1] = y = r;
+	 x = y;
+	 y = r;
 	goto L;
 }
 
 /* (+          )   */
-Lplus()
+void
+Lplus(void)
 {
         int i, j;
 	
@@ -1072,7 +878,8 @@ Lplus()
 	vs_top = vs_base+1;
 }
 
-Lminus()
+void
+Lminus(void)
 {
 	int i, j;
 
@@ -1090,7 +897,8 @@ Lminus()
 	vs_top = vs_base+1;
 }
 
-Ltimes()
+void
+Ltimes(void)
 {
 	int i, j;
 
@@ -1106,7 +914,8 @@ Ltimes()
 	vs_top = vs_base+1;
 }
 
-Ldivide()
+void
+Ldivide(void)
 {
 	int i, j;
 
@@ -1124,25 +933,26 @@ Ldivide()
 	vs_top = vs_base+1;
 }
 
-Lone_plus()
+void
+Lone_plus(void)
 {
-	object x;
 	
 	check_arg(1);
 	check_type_number(&vs_base[0]);
 	vs_base[0] = one_plus(vs_base[0]);
 }
 
-Lone_minus()
+void
+Lone_minus(void)
 {
-	object x;
 	
 	check_arg(1);
 	check_type_number(&vs_base[0]);
 	vs_base[0] = one_minus(vs_base[0]);
 }
 
-Lconjugate()
+void
+Lconjugate(void)
 {
 	object	c, i;
 
@@ -1153,11 +963,12 @@ Lconjugate()
 		i = number_negate(c->cmp.cmp_imag);
 		vs_push(i);
 		vs_base[0] = make_complex(c->cmp.cmp_real, i);
-		vs_pop;
+		vs_popp;
 	}
 }
 
-Lgcd()
+void
+Lgcd(void)
 {
 	int i, narg;
 
@@ -1178,7 +989,8 @@ Lgcd()
 	vs_top = vs_base+1;
 }
 
-Llcm()
+void
+Llcm(void)
 {
 	object t, g;
 	int i, narg;
@@ -1199,20 +1011,22 @@ Llcm()
 		g = get_gcd(vs_base[0], vs_base[i]);
 		vs_push(g);
 		vs_base[0] = number_divide(t, g);
-		vs_pop;
-		vs_pop;
+		vs_popp;
+		vs_popp;
 	}
 	if (number_minusp(vs_base[0]))
 		vs_base[0] = number_negate(vs_base[0]);
 	vs_top = vs_base+1;
 }
 
-zero_divisor()
+static void
+zero_divisor(void)
 {
 	FEerror("Zero divisor.", 0);
 }
 
-init_num_arith()
+void
+init_num_arith(void)
 {
 	make_function("+", Lplus);
 	make_function("-", Lminus);
