@@ -29,10 +29,10 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #define IN_NUM_CO
 
 #define NEED_MP_H
+
 #include "include.h"
 #include "num_include.h"
 
-
 object plus_half, minus_half;
 
 #ifdef CONVEX
@@ -94,9 +94,8 @@ object plus_half, minus_half;
 	LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL
 */
 #endif
-integer_decode_double(d, hp, lp, ep, sp)
-double d;
-int *hp, *lp, *ep, *sp;
+static void
+integer_decode_double(double d, int *hp, int *lp, int *ep, int *sp)
 {
 	int h, l;
 
@@ -121,8 +120,13 @@ int *hp, *lp, *ep, *sp;
 	h = h >> 1;
 #endif
 #ifdef IEEEFLOAT
-	*ep = ((h & 0x7ff00000) >> 20) - 1022 - 53;
-	h = (h & 0x000fffff | 0x00100000);
+	if (ISNORMAL(d)) {
+	  *ep = ((h & 0x7ff00000) >> 20) - 1022 - 53;
+	  h = ((h & 0x000fffff) | 0x00100000);
+	} else {
+	  *ep = ((h & 0x7fe00000) >> 20) - 1022 - 53 + 1;
+	  h = (h & 0x001fffff);
+	}
 #endif
 #ifdef S3000
 	*ep = ((h & 0x7f000000) >> 24) - 64 - 14;
@@ -178,9 +182,8 @@ int *hp, *lp, *ep, *sp;
 	SEEEEEEEMMMMMMMMMMMMMMMMMMMMMMMM
 */
 #endif
-integer_decode_float(d, mp, ep, sp)
-double d;
-int *mp, *ep, *sp;
+static void
+integer_decode_float(double d, int *mp, int *ep, int *sp)
 {
 	float f;
 	int m;
@@ -202,8 +205,13 @@ int *mp, *ep, *sp;
 
 #endif
 #ifdef IEEEFLOAT
-	*ep = ((m & 0x7f800000) >> 23) - 126 - 24;
-	*mp = m & 0x007fffff | 0x00800000;
+	if (ISNORMAL(f)) {
+	  *ep = ((m & 0x7f800000) >> 23) - 126 - 24;
+	  *mp = (m & 0x007fffff) | 0x00800000;
+	} else {
+	  *ep = ((m & 0x7f000000) >> 23) - 126 - 24 + 1;
+	  *mp = m & 0x00ffffff;
+	}
 #endif
 #ifdef MV
 
@@ -216,9 +224,8 @@ int *mp, *ep, *sp;
 	*sp = (f > 0.0 ? 1 : -1);
 }
 
-int
-double_exponent(d)
-double d;
+static int
+double_exponent(double d)
 {
 	if (d == 0.0)
 		return(0);
@@ -232,7 +239,7 @@ double d;
 #ifdef NS32K
 
 #else
-	return((((*((int *)(&d) + HIND)) & 0x7ff00000) >> 20) - 1022);
+	return ((((*((int *)(&d) + HIND)) & 0x7ff00000) >> 20) - 1022);
 #endif
 #endif
 #ifdef MV
@@ -243,15 +250,14 @@ double d;
 #endif
 }
 
-double
-set_exponent(d, e)
-double d;
-int e;
+static double
+set_exponent(double d, int e)
 {
 	double dummy;
 
 	if (d == 0.0)
 		return(0.0);
+	  
 	*((int *)(&d) + HIND)
 #ifdef VAX
 	= *(int *)(&d) & 0xffff807f | ((e + 128) << 7) & 0x7f80;
@@ -263,7 +269,7 @@ int e;
 #ifdef NS32K
 
 #else
-	= *((int *)(&d) + HIND) & 0x800fffff | ((e + 1022) << 20) & 0x7ff00000;
+	= (*((int *)(&d) + HIND) & 0x800fffff) | (((e + 1022) << 20) & 0x7ff00000);
 #endif
 #endif
 #ifdef MV
@@ -278,12 +284,11 @@ int e;
 
 
 object
-double_to_integer(d)
-double d;
+double_to_integer(double d)
 {
 	int h, l, e, s;
-	object x, y;
-	object shift_integer();
+	object x;
+	object shift_integer(object x, int w);
 	vs_mark;
 
 	if (d == 0.0)
@@ -314,7 +319,7 @@ double d;
 #endif
 		return(make_fixnum(s*h));
 	}
-	if (h != 0)
+	if (h != 0 || l<0)
 		x = bignum2(h, l);
 	else
 		x = make_fixnum(l);
@@ -342,28 +347,28 @@ double d;
 	return(x);
 }
 
-object
-remainder(x, y, q)
-object x, y, q;
+static object
+num_remainder(object x, object y, object q)
 {
 	object z;
 
 	z = number_times(q, y);
 	vs_push(z);
 	z = number_minus(x, z);
-	vs_pop;
+	vs_popp;
 	return(z);
 }
 
 /* Coerce X to single-float if one arg,
    otherwise coerce to same float type as second arg */
 
-Lfloat()
+void
+Lfloat(void)
 {
 	double	d;
 	int narg;
 	object	x;
-	enum type t;
+	enum type t=t_other;
 
 	narg = vs_top - vs_base;
 	if (narg < 1)
@@ -410,7 +415,8 @@ Lfloat()
 	vs_push(x);
 }
 
-Lnumerator()
+void
+Lnumerator(void)
 {
 	check_arg(1);
 	check_type_rational(&vs_base[0]);
@@ -418,7 +424,8 @@ Lnumerator()
 		vs_base[0] = vs_base[0]->rat.rat_num;
 }
 
-Ldenominator()
+void
+Ldenominator(void)
 {
 	check_arg(1);
 	check_type_rational(&vs_base[0]);
@@ -428,12 +435,13 @@ Ldenominator()
 		vs_base[0] = small_fixnum(1);
 }
 
-Lfloor()
+void
+Lfloor(void)
 {
 	object x, y, q, q1;
 	double d;
 	int n;
-	object one_minus();
+	object one_minus(object x);
 
 	n = vs_top - vs_base;
 	if (n == 0)
@@ -531,7 +539,7 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -544,17 +552,20 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
+	default:
+	  break;
 	}
 }
 
-Lceiling()
+void
+Lceiling(void)
 {
 	object x, y, q, q1;
 	double d;
 	int n;
-	object one_plus();
+	object one_plus(object x);
 
 	n = vs_top - vs_base;
 	if (n == 0)
@@ -652,7 +663,7 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -665,12 +676,15 @@ TWO_ARG:
 			q1 = q1;
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
+	default:
+	  break;
 	}
 }
 
-Ltruncate()
+void
+Ltruncate(void)
 {
 	object x, y, q, q1;
 	int n;
@@ -739,7 +753,7 @@ TWO_ARG:
 		q1 = integer_divide1(q->rat.rat_num, q->rat.rat_den);
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -747,17 +761,20 @@ TWO_ARG:
 		q1 = double_to_integer(number_to_double(q));
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
+	default:
+	  break;
 	}
 }
 
-Lround()
+void
+Lround(void)
 {
 	object x, y, q, q1, r;
 	double d;
 	int n, c;
-	object one_plus(), one_minus();
+	object one_plus(object x), one_minus(object x);
 
 	n = vs_top - vs_base;
 	if (n == 0)
@@ -856,7 +873,7 @@ TWO_ARG:
 			q1 = one_minus(q1);
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
 
 	case t_shortfloat:
@@ -877,19 +894,23 @@ TWO_ARG:
 		}
 		vs_base = vs_top;
 		vs_push(q1);
-		vs_push(remainder(x, y, q1));
+		vs_push(num_remainder(x, y, q1));
 		return;
+	default:
+	  break;
 	}
 }
 
-Lmod()
+void
+Lmod(void)
 {
 	check_arg(2);
 	Lfloor();
 	vs_base++;
 }
 
-Lrem()
+void
+Lrem(void)
 {
 	check_arg(2);
 	Ltruncate();
@@ -897,7 +918,8 @@ Lrem()
 }
 
 
-Ldecode_float()
+void
+Ldecode_float(void)
 {
 	object x;
 	double d;
@@ -916,7 +938,17 @@ Ldecode_float()
 		d = -d;
 		s = -1;
 	}
-	e = double_exponent(d);
+	e=0;
+	if (!ISNORMAL(d)) {
+	  unsigned hp,lp,sp;
+
+	  integer_decode_double(d,&hp,&lp,&e,&sp);
+	  if (hp!=0 || lp<0)
+	    d=number_to_double(bignum2(hp, lp));
+	  else
+	    d=lp;
+	}
+	e += double_exponent(d);
 	d = set_exponent(d, 0);
 	vs_top = vs_base;
 	if (type_of(x) == t_shortfloat) {
@@ -930,11 +962,12 @@ Ldecode_float()
 	}
 }
 
-Lscale_float()
+void
+Lscale_float(void)
 {
 	object x;
 	double d;
-	int e, k;
+	int e, k=0;
 
 	check_arg(2);
 	check_type_float(&vs_base[0]);
@@ -955,8 +988,10 @@ Lscale_float()
 
 #endif
 #ifdef IEEEFLOAT
-	if (type_of(x) == t_shortfloat && (e <= -126 || e >= 130) ||
-	    type_of(x) == t_longfloat && (e <= -1022 || e >= 1026))
+	  /* Upper bound not needed, handled by floating point overflow */
+	  /* this checks if we're in the denormalized range */
+	if (!ISNORMAL(d) || (type_of(x) == t_shortfloat && e <= -126/*  || e >= 130 */) ||
+	    (type_of(x) == t_longfloat && (e <= -1022 /* || e >= 1026 */)))
 #endif
 #ifdef MV
 
@@ -964,16 +999,22 @@ Lscale_float()
 #ifdef S3000
 	if (e < -64 || e >= 64)
 #endif
-		FEerror("~S is an illegal exponent.", 1, vs_base[1]);
-	d = set_exponent(d, e);
-	vs_pop;
+/* 		FEerror("~S is an illegal exponent.", 1, vs_base[1]); */
+	  {
+	    for (;k>0;d*=2.0,k--);
+	    for (;k<0;d*=0.5,k++);
+	  }
+	else
+	  d = set_exponent(d, e);
+	vs_popp;
 	if (type_of(x) == t_shortfloat)
 		vs_base[0] = make_shortfloat((shortfloat)d);
 	else
 		vs_base[0] = make_longfloat(d);
 }
 
-Lfloat_radix()
+void
+Lfloat_radix(void)
 {
 	check_arg(1);
 	check_type_float(&vs_base[0]);
@@ -994,7 +1035,8 @@ Lfloat_radix()
 #endif
 }
 
-Lfloat_sign()
+void
+Lfloat_sign(void)
 {
 	object x;
 	int narg;
@@ -1032,7 +1074,8 @@ Lfloat_sign()
 		vs_push(make_longfloat(f));
 }
 
-Lfloat_digits()
+void
+Lfloat_digits(void)
 {
 	check_arg(1);
 	check_type_float(&vs_base[0]);
@@ -1042,7 +1085,8 @@ Lfloat_digits()
 		vs_base[0] = small_fixnum(53);
 }
 
-Lfloat_precision()
+void
+Lfloat_precision(void)
 {
 	object x;
 
@@ -1075,7 +1119,8 @@ Lfloat_precision()
 #endif
 }
 
-Linteger_decode_float()
+void
+Linteger_decode_float(void)
 {
 	object x;
 	int h, l, e, s;
@@ -1086,7 +1131,7 @@ Linteger_decode_float()
 	vs_base = vs_top;
 	if (type_of(x) == t_longfloat) {
 		integer_decode_double(lf(x), &h, &l, &e, &s);
-		if (h != 0)
+		if (h != 0 || l<0)
 			vs_push(bignum2(h, l));
 		else
 			vs_push(make_fixnum(l));
@@ -1100,9 +1145,10 @@ Linteger_decode_float()
 	}
 }
 
-Lcomplex()
+void
+Lcomplex(void)
 {
-	object	x, r, i;
+	object	r, i;
 	int narg;
 
 	narg = vs_top - vs_base;
@@ -1122,9 +1168,10 @@ Lcomplex()
 	vs_push(make_complex(r, i));
 }
 
-Lrealpart()
+void
+Lrealpart(void)
 {
-	object	r, x;
+	object	x;
 
 	check_arg(1);
 	check_type_number(&vs_base[0]);
@@ -1133,7 +1180,8 @@ Lrealpart()
 		vs_base[0] = x->cmp.cmp_real;
 }
 
-Limagpart()
+void
+Limagpart(void)
 {
 	object x;
 
@@ -1155,27 +1203,20 @@ Limagpart()
 	case t_complex:
 		vs_base[0] = x->cmp.cmp_imag;
 		break;
+	default:
+	  break;
 	}
 }
 
-static float sf1,sf2;
-static sf_eql()
-{return(sf1==sf2);}
-
-static lf_eql(a,b)
-     double a,b;
-{return(a==b);}
-#define LF_EQL(a,b) lf_eql((double)(a),(double)(b))
-#define SF_EQL(a,b) (sf1=a,sf2=b,sf_eql())
-
-init_num_co()
+void
+init_num_co(void)
 {
-	int l[2];
-	float smallest_float, biggest_float;
-	double smallest_double, biggest_double;
+	float smallest_float, smallest_norm_float, biggest_float;
+	double smallest_double, smallest_norm_double, biggest_double;
 	float float_epsilon, float_negative_epsilon;
 	double double_epsilon, double_negative_epsilon;
 
+
 #ifdef VAX
 	l[0] = 0x80;
 	l[1] = 0;
@@ -1249,33 +1290,6 @@ init_num_co()
         printf("\n Used fake values for float max and mins ");
 #endif
 #endif
-#endif
-
-#ifdef MV
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #endif
 
 #if defined(S3000) && ~defined(DBL_MAX_10_EXP)
@@ -1305,53 +1319,51 @@ init_num_co()
 	biggest_double = *(double *)l;
 #endif
 
-	
+
 #ifdef DBL_MAX_10_EXP
 	biggest_double = DBL_MAX;
-	smallest_double = DBL_MIN;
-	smallest_float = FLT_MIN;
+	smallest_norm_double = DBL_MIN;
+	smallest_norm_float = FLT_MIN;
 	biggest_float = FLT_MAX;
 #endif
 	
+	{
+	  
+	  volatile double rd,dd,td,td1;
+	  volatile float  rf,df,tf,tf1;
+	  int i,j;
+#define MAX 500
+	  
+	  for (rf=1.0f,df=0.5f,i=j=0;i<MAX && j<MAX && df!=1.0f;i++,df=1.0f-(0.5f*(1.0f-df)))
+	    for (tf=rf,tf1=tf+1.0f,j=0;j<MAX && tf1!=1.0f;j++,rf=tf,tf*=df,tf1=tf+1.0f);
+	  if (i==MAX||j==MAX)
+	    printf("WARNING, cannot calculate float_epsilon: %d %d %f   %f %f %f\n",i,j,rf,df,tf,tf1);
+	  float_epsilon=rf;
 
+	  for (rf=1.0f,df=0.5f,i=j=0;i<MAX && j<MAX && df!=1.0f;i++,df=1.0f-(0.5f*(1.0f-df)))
+	    for (tf=rf,tf1=1.0f-tf,j=0;j<MAX && tf1!=1.0f;j++,rf=tf,tf*=df,tf1=1.0f-tf);
+	  if (i==MAX||j==MAX)
+	    printf("WARNING, cannot calculate float_negative_epsilon: %d %d %f   %f %f %f\n",i,j,rf,df,tf,tf1);
+	  float_negative_epsilon=rf;
+	  
+	  for (rd=1.0,dd=0.5,i=j=0;i<MAX && j<MAX && dd!=1.0;i++,dd=1.0-(0.5*(1.0-dd)))
+	    for (td=rd,td1=td+1.0,j=0;j<MAX && td1!=1.0;j++,rd=td,td*=dd,td1=td+1.0);
+	  if (i==MAX||j==MAX)
+	    printf("WARNING, cannot calculate double_epsilon: %d %d %f   %f %f %f\n",i,j,rd,dd,td,td1);
+	  double_epsilon=rd;
 
+	  for (rd=1.0,dd=0.5,i=j=0;i<MAX && j<MAX && dd!=1.0;i++,dd=1.0-(0.5*(1.0-dd)))
+	    for (td=rd,td1=1.0-td,j=0;j<MAX && td1!=1.0;j++,rd=td,td*=dd,td1=1.0-td);
+	  if (i==MAX||j==MAX)
+	    printf("WARNING, cannot calculate double_negative_epsilon: %d %d %f   %f %f %f\n",i,j,rd,dd,td,td1);
+	  double_negative_epsilon=rd;
+	  
+	}
 
-/* We want the smallest number not satisfying something,
-   and so we go quickly down, and then back up.  We have
-   to use a function call for test, since in line code may keep
-   too much precision, while the usual lisp eql,is not
-   in line.
-   We use SMALL as a multiple to come back up by.
-*/
-
-#define SMALL 1.05	
-	for (float_epsilon = 1.0;
-	     !SF_EQL((float)(1.0 + float_epsilon),(float)1.0);
-	     float_epsilon /= 2.0)
-		;
-	while(SF_EQL((float)(1.0 + float_epsilon),(float)1.0))
-	  float_epsilon=float_epsilon*SMALL;
-	for (float_negative_epsilon = 1.0;
-	     !SF_EQL((float)(1.0 - float_negative_epsilon) ,(float)1.0);
-	     float_negative_epsilon /= 2.0)
-		;
-	while(SF_EQL((float)(1.0 - float_negative_epsilon) ,(float)1.0))
-	  float_negative_epsilon=float_negative_epsilon*SMALL;
-	for (double_epsilon = 1.0;
-	     !(LF_EQL(1.0 + double_epsilon, 1.0));
-	     double_epsilon /= 2.0)
-		;
-	while((LF_EQL(1.0 + double_epsilon, 1.0)))
-	  double_epsilon=double_epsilon*SMALL;
-	  ;
-	for (double_negative_epsilon = 1.0;
-	     !LF_EQL(1.0 - double_negative_epsilon , 1.0);
-	     double_negative_epsilon /= 2.0)
-		;
-	while(LF_EQL(1.0 - double_negative_epsilon , 1.0))
-	  double_negative_epsilon=double_negative_epsilon*SMALL;
-	  ;
 	
+#ifdef IEEEFLOAT
+	/* Maybe check for "right" answer here */
+#endif
 
 	make_constant("MOST-POSITIVE-SHORT-FLOAT",
 		      make_shortfloat(biggest_float));
@@ -1407,6 +1419,24 @@ init_num_co()
 	make_constant("LONG-FLOAT-NEGATIVE-EPSILON",
 		      make_longfloat(double_negative_epsilon));
 
+	/* Normalized constants added, CM */
+	make_constant("LEAST-POSITIVE-NORMALIZED-SHORT-FLOAT",
+		      make_shortfloat(smallest_norm_float));
+	make_constant("LEAST-NEGATIVE-NORMALIZED-SHORT-FLOAT",
+		      make_shortfloat(-smallest_norm_float));
+	make_constant("LEAST-POSITIVE-NORMALIZED-SINGLE-FLOAT",
+		      make_longfloat(smallest_norm_double));
+	make_constant("LEAST-NEGATIVE-NORMALIZED-SINGLE-FLOAT",
+		      make_longfloat(-smallest_norm_double));
+	make_constant("LEAST-POSITIVE-NORMALIZED-DOUBLE-FLOAT",
+		      make_longfloat(smallest_norm_double));
+	make_constant("LEAST-NEGATIVE-NORMALIZED-DOUBLE-FLOAT",
+		      make_longfloat(-smallest_norm_double));
+	make_constant("LEAST-POSITIVE-NORMALIZED-LONG-FLOAT",
+		      make_longfloat(smallest_norm_double));
+	make_constant("LEAST-NEGATIVE-NORMALIZED-LONG-FLOAT",
+		      make_longfloat(-smallest_norm_double));
+
 	plus_half = make_ratio(small_fixnum(1), small_fixnum(2));
 	enter_mark_origin(&plus_half);
 
